MockTransport class final
Deterministic in-memory transport for tests.
Requests are recorded in requests, then passed to the responder supplied to the constructor.
- Implemented types
Constructors
- MockTransport(MockResponder _responder)
Properties
- capability → PlatformCapability
-
Capabilities exposed by this transport.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
requests
→ List<
Request> -
Requests sent through this transport.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> -
Releases transport resources.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
Request request, Context context) → Future< Response> -
Sends a prepared
request.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited